@@ -50,7 +50,7 @@ lsm_l_lpi.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_l_lpi_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -66,7 +66,7 @@ lsm_l_lpi.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_l_lpi_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -82,7 +82,7 @@ lsm_l_lpi.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_l_lpi_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -100,7 +100,7 @@ lsm_l_lpi.stars <- function(landscape, directions = 8) {
                      FUN = lsm_l_lpi_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -116,7 +116,7 @@ lsm_l_lpi.list <- function(landscape, directions = 8) {
                      FUN = lsm_l_lpi_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
